==> ksteak-0.3.2.tar.gz: ksteak-0.3.2/ksteak/dockwidget.h <==
/***************************************************************************
                          dockwidget.h  -  description
                             -------------------
    begin                : Fri Nov 14 2000
    copyright            : (C) 2000 by Michael Heidecke
    email                : heidecke@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DOCKWIDGET_H
#define DOCKWIDGET_H

#include <kpopupmenu.h>
#include <qlabel.h>
#include <kdockwindow.h>

/**
  *@author Michael Heidecke
  */

class dockwidget : public KDockWindow
{
  Q_OBJECT
    public: 
  dockwidget(QWidget * parent=0, const char * name=0);
  ~dockwidget();
  public slots:
    void slotMenuClicked(int);
 signals:
  void undock(void);
  void done(void);
  void translate(void);
 protected:
  void mousePressEvent(QMouseEvent *e);
 private:
  KPopupMenu *popup_menu;
};

#endif

==> ksteak-0.4.3.tar.gz: ksteak-0.4.3/ksteak/dockwidget.h <==
/***************************************************************************
                          dockwidget.h  -  description
                             -------------------
    begin                : Fri Nov 14 2000
    copyright            : (C) 2000 by Michael Heidecke
    email                : heidecke@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DOCKWIDGET_H
#define DOCKWIDGET_H

#include <kpopupmenu.h>
#include <qlabel.h>
#include <ksystemtray.h>
#include <kdatetbl.h>
#include <qtextview.h>
#include <qlineedit.h>

/**
  *@author Michael Heidecke
  */

class dockwidget : public KSystemTray
{
  Q_OBJECT
    public: 
  dockwidget(QWidget * parent=0, const char * name=0);
  ~dockwidget(); 
  KPopupFrame *mypop;
  QTextView *myview;

  void getTranslation(const QString &szWord);
 public slots:
    void slotMenuClicked(int);
 //void slotTranslation(void);
 signals:
  void undock(void);
  void done(void);
  void configure(void);
  void translate( const QString & );
 protected:
  void mousePressEvent(QMouseEvent *e);
 private:
  KPopupMenu *popup_menu;
};
#endif
